


TOTAL = {'likes': 0,
         'unlikes': 0,
         'follows': 0,
         'unfollows': 0,
         'comments': 0,
         'blocks': 0,
         'unblocks': 0,
         'texts': 0,
         'archived': 0,
         'unarchived': 0,
         'uploads': 0
         }


DELAY = {'like': 10,
         'unlike': 10,
         'follow': 5,
         'unfollow': 3,
         'comment': 60,
         'block': 30,
         'unblock': 30,
         'text': 5,
         'upload': 30,
         'delete': 30,
         'error': 30,

         'usual': 4,
         'getter': 70
    }


MAX_PER_DAY = {'likes': 1000,
               'unlikes': 1000,
               'follows': 350,
               'unfollows': 350,
               'comments': 100,
               'blocks': 100,
               'unblocks': 100,
               'texts': 300
               }
